@@ -1,6 +1,6 @@
 package GeoIP2::Record::Country;
 {
-  $GeoIP2::Record::Country::VERSION = '0.0300';
+  $GeoIP2::Record::Country::VERSION = '0.0301';
 }
 
 use strict;
@@ -24,7 +24,7 @@ GeoIP2::Record::Country - Contains data for the country record associated with a
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -37,9 +37,9 @@ version 0.0300
       license_key => 'abcdef123456',
   );
 
-  my $city = $client->city_isp_org( ip => '24.24.24.24' );
+  my $omni = $client->omni( ip => '24.24.24.24' );
 
-  my $country_rec = $city->country();
+  my $country_rec = $omni->country();
   say $country_rec->name();
 
 =head1 DESCRIPTION
@@ -68,7 +68,7 @@ This attribute is returned by all end points.
 =head2 $country_rec->iso_code()
 
 This returns the two-character ISO 3166-1
-(http://en.wikipedia.org/wiki/ISO_3166-1) alpha code for the country.
+(L<http://en.wikipedia.org/wiki/ISO_3166-1>) alpha code for the country.
 
 This attribute is returned by all end points.
 
@@ -79,7 +79,7 @@ C<languages> argument that was passed to the record's constructor. This will
 be passed through from the L<GeoIP2::WebService::Client> object you used to
 fetch the data that populated this record.
 
-If the record does not have a name in any of languages you asked for, this
+If the record does not have a name in any of the languages you asked for, this
 method returns C<undef>.
 
 This attribute is returned by all end points.
@@ -92,10 +92,28 @@ language codes.
 
 This attribute is returned by all end points.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dave Rolsky <drolsky@maxmind.com>
 
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Olaf Alders <oalders@maxmind.com>
+
+=back
+
+=head1 CONTRIBUTOR
+
+Graham Knop <haarg@haarg.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by MaxMind, Inc..
