@@ -1,6 +1,6 @@
 package GeoIP2::Record::Location;
 {
-  $GeoIP2::Record::Location::VERSION = '0.0300';
+  $GeoIP2::Record::Location::VERSION = '0.0301';
 }
 
 use strict;
@@ -54,7 +54,7 @@ GeoIP2::Record::Location - Contains data for the location record associated with
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -67,9 +67,9 @@ version 0.0300
       license_key => 'abcdef123456',
   );
 
-  my $city = $client->city_isp_org( ip => '24.24.24.24' );
+  my $omni = $client->omni( ip => '24.24.24.24' );
 
-  my $location_rec = $city->location();
+  my $location_rec = $omni->location();
   say $location_rec->name();
 
 =head1 DESCRIPTION
@@ -105,21 +105,39 @@ This attribute is returned by all end points except the Country end point.
 
 This returns the metro code of the location if the location is in the US.
 MaxMind returns the same metro codes as the Google AdWords API
-(https://developers.google.com/adwords/api/docs/appendix/cities-DMAregions).
+(L<https://developers.google.com/adwords/api/docs/appendix/cities-DMAregions>).
 
 This attribute is returned by all end points except the Country end point.
 
 =head2 $location_rec->time_zone()
 
-This returns the time zone associated with location, as specified by the IANA
-Time Zone Database (http://www.iana.org/time-zones), e.g., "America/New_York".
+This returns the time zone associated with a location, as specified by the IANA
+Time Zone Database (L<http://www.iana.org/time-zones>), e.g., "America/New_York".
 
 This attribute is returned by all end points except the Country end point.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dave Rolsky <drolsky@maxmind.com>
 
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Olaf Alders <oalders@maxmind.com>
+
+=back
+
+=head1 CONTRIBUTOR
+
+Graham Knop <haarg@haarg.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by MaxMind, Inc..
