@@ -1,6 +1,6 @@
 package GeoIP2::Record::Subdivision;
 {
-  $GeoIP2::Record::Subdivision::VERSION = '0.0300';
+  $GeoIP2::Record::Subdivision::VERSION = '0.0301';
 }
 
 use strict;
@@ -44,7 +44,7 @@ GeoIP2::Record::Subdivision - Contains data for the subdivision record associate
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -57,9 +57,9 @@ version 0.0300
       license_key => 'abcdef123456',
   );
 
-  my $city = $client->city_isp_org( ip => '24.24.24.24' );
+  my $omni = $client->omni( ip => '24.24.24.24' );
 
-  my $subdivision_rec = $city->subdivision();
+  my $subdivision_rec = $omni->subdivision();
   say $subdivision_rec->name();
 
 =head1 DESCRIPTION
@@ -90,7 +90,7 @@ This attribute is returned by all end points except the Country end point.
 =head2 $subdivision_rec->iso_code()
 
 This returns a string up to three characters long contain the subdivision portion
-of the ISO 3166-2 code (http://en.wikipedia.org/wiki/ISO_3166-2).
+of the ISO 3166-2 code (L<http://en.wikipedia.org/wiki/ISO_3166-2>).
 
 This attribute is returned by all end points except the Country end point.
 
@@ -101,7 +101,7 @@ C<languages> argument that was passed to the record's constructor. This will
 be passed through from the L<GeoIP2::WebService::Client> object you used to
 fetch the data that populated this record.
 
-If the record does not have a name in any of languages you asked for, this
+If the record does not have a name in any of the languages you asked for, this
 method returns C<undef>.
 
 This attribute is returned by all end points except the Country end point.
@@ -114,10 +114,28 @@ language codes.
 
 This attribute is returned by all end points except the Country end point.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Dave Rolsky <drolsky@maxmind.com>
 
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Olaf Alders <oalders@maxmind.com>
+
+=back
+
+=head1 CONTRIBUTOR
+
+Graham Knop <haarg@haarg.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by MaxMind, Inc..
